CREATE TABLE IF NOT EXISTS mythexport (id int(11) NOT NULL auto_increment, file varchar(65) NOT NULL, title varchar(255) NOT NULL, subtitle varchar(255) default NULL, description varchar(255) default NULL, pubDate datetime NOT NULL, delDate datetime default NULL, airDate datetime NOT NULL, PRIMARY KEY (id));

DROP TABLE IF EXISTS mythexport_job_queue;

CREATE TABLE IF NOT EXISTS mythexport_job_queue (id int(11) NOT NULL auto_increment, `type` varchar(25) NOT NULL, param longtext default NULL, description varchar(255) default NULL, PRIMARY KEY (id));

DROP PROCEDURE IF EXISTS addcol;

delimiter '//'
CREATE PROCEDURE addcol() BEGIN
	IF NOT EXISTS(
		SELECT * FROM information_schema.COLUMNS
		WHERE COLUMN_NAME='podcastName' AND TABLE_NAME='mythexport'
	)
	THEN
		ALTER IGNORE TABLE mythexport ADD podcastName varchar(25) default NULL;
	END IF;
END;
//
delimiter ';'
CALL addcol();
DROP PROCEDURE addcol;
